@@ -125,8 +125,10 @@
 #define TITRAQ_DEFWHATBAR       true
 
 // Other value preferences
-#define TITRAQ_PREFSORT         "sortorder"
-#define TITRAQ_DEFSORT          TITRAQ_IDXDATE
+#define TITRAQ_PREFSORTCOL      "sortordering"
+#define TITRAQ_DEFSORTCOL       TITRAQ_IDXDATE
+#define TITRAQ_PREFSORTDIR      "sortascending"
+#define TITRAQ_DEFSORTDIR       true
 
 // Other string constants
 #define TITRAQ_DATEZERO         "0000-00-00"
