@@ -41,7 +41,6 @@
 #include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
 #include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
 
-#include <iostream>
 
 //
 // Convenience method to load accounts from a file
@@ -263,8 +262,11 @@ void Titraqform::loadData(QTextStream &Tstream)
         }
     }
 
-    // Start sorting order correctly according to user preferences
-    m_pMaintable->sortColumn((int)m_pPrefs->getNumber(TITRAQ_PREFSORT, TITRAQ_DEFSORT));
+    // Start sorting order and direction correctly according to user preferences
+    int nSortcol = (int)m_pPrefs->getNumber(TITRAQ_PREFSORTCOL, TITRAQ_DEFSORTCOL);
+    bool bSortdir = m_pPrefs->getBool(TITRAQ_PREFSORTDIR, TITRAQ_DEFSORTDIR);
+    m_pMaintable->setSortdir(!bSortdir); // Hack! Fake sortdir so we start right
+    m_pMaintable->sortColumn(nSortcol, bSortdir);
 
     // Write nonsaving line numbers for all rows
     for (int nIter = m_pMaintable->numRows() - 1; nIter >= 0; nIter--)
