@@ -48,6 +48,10 @@
 #include <qlayout.h>
 #include <qfile.h>
 
+#ifdef HAVE_CONFIG_H
+#include "ac_config.h"
+#endif
+
 #include "as_except.h"  // Exception classes
 #include "as_const.h"   // For general constants
 #include "as_pref.h"    // For class Preferences
@@ -122,6 +126,7 @@ public:
     QAction     *m_pAddrowact,    *m_pDelrowact;
     QAction     *m_pRefreshact,   *m_pCutact;
     QAction     *m_pCopyact,      *m_pPasteact;
+    QAction     *m_pSynciiopact,  *m_pSyncsoapact;
 
     // Table, cells, and entries in package layout
     TiTable     *m_pMaintable;
@@ -150,6 +155,8 @@ protected slots:
     void addEntry(int nRows= -1);       // Add task entries to the list
     void delEntry(int nRows= -1);       // Delete task entries from the list
     void refreshDisplay(void);          // Refresh the display of all data items
+    void syncIiop(void);                // Syncronize data with server using IIOP
+    void syncSoap(void);                // Syncronize data with server using SOAP
     void newDoc(void);                  // Make and display a new document window
     void openDoc(void);                 // Open and display an existing document
     void saveFile(void);                // Serialize to the current file
@@ -160,7 +167,7 @@ protected slots:
     void aboutQt(void);                 // Learn more about Qt
     void selAll(void);                  // Edit menu select all
     void inplaceEdit(int, int, int, const QPoint &); // Enter in place edit mode
-    void updEdit(int, int);             // Update edit controls
+    void updEdit(int, int nCol = 0);    // Update edit controls
     void validateData(int, int);        // Validate one row of matrix data
     void updSizes(int, int, int);       // Update edit sizes
     void dataChanged(int, int);         // Timesheet data changed
@@ -196,6 +203,7 @@ protected slots:
     void showAmountcol(void);           // View menu show Amounts column
     void showTaskcol(void);             // View menu show Tasks column
     void showRemarkcol(void);           // View menu show Remarks column
+    void genReport(void);               // Generate a local formatted report
     void savePrefs(void);               // Save user preferences
 
 protected:
