@@ -387,7 +387,8 @@ void Titraqform::saveAs(void)
             }
         }
         else
-            saveFile(); // Finish off by calling the save action
+            this->setFilename(Filestring);  // Set filename of object first
+            this->saveFile();               // Finish by calling the save action
     }
     else {
         // User did not select a valid file and push okay button
